@@ -127,68 +127,6 @@ def check_spades(spades_path):
                         '"spades.py" location, not "spades")')
 
 
-def find_pilon(pilon_path, java_path, args):
-    """
-    Makes sure the Pilon executable is available. Unlike the other tools, Pilon's target name may
-    change based on the version (e.g. pilon-1.18.jar, pilon-1.19.jar, etc.). This function will
-    therefore set args.pilon_path to the first matching jar file it finds.
-    """
-    # If the user specified a Pilon path other than the default, then it must exist.
-    if args.pilon_path != 'pilon' and args.pilon_path is not None:
-        args.pilon_path = os.path.abspath(args.pilon_path)
-        if args.pilon_path.endswith('.jar'):
-            if not os.path.isfile(args.pilon_path):
-                return 'not found'
-        elif shutil.which(args.pilon_path) is None:
-            return 'not found'
-
-    # If pilon_path is the default and exists, then that's great!
-    elif args.pilon_path == 'pilon' and shutil.which(args.pilon_path) is not None:
-        args.pilon_path = shutil.which(args.pilon_path)
-
-    # If the user didn't specify a path and 'pilon' doesn't work, then we need to look for a
-    # Pilon jar file.
-    else:
-        found_pilon_path = get_pilon_jar_path(pilon_path)
-        if found_pilon_path:
-            args.pilon_path = found_pilon_path
-        else:
-            return 'not found'
-
-    # Now that we've found Pilon, run the help command to make sure it works.
-    if args.pilon_path.endswith('.jar'):
-        test_command = [java_path, '-jar', args.pilon_path, '--help']
-    else:
-        test_command = [args.pilon_path, '--help']
-    try:
-        pilon_help_out = subprocess.check_output(test_command, stderr=subprocess.STDOUT).decode()
-        if 'pilon' not in pilon_help_out.lower():
-            raise OSError
-    except (FileNotFoundError, OSError, subprocess.CalledProcessError):
-        return 'bad'
-
-    return 'good'
-
-
-def get_pilon_jar_path(pilon_path):
-    """
-    Returns the path to pilon.jar. If the given path is correct, it just returns that, as an
-    absolute path. Otherwise it tries to find it.
-    """
-    if pilon_path and os.path.isfile(pilon_path):
-        return os.path.abspath(pilon_path)
-    for directory in os.environ['PATH'].split(':'):
-        try:
-            path_files = [f for f in os.listdir(directory)
-                          if os.path.isfile(os.path.join(directory, f))]
-        except FileNotFoundError:
-            path_files = []
-        pilon_jars = [f for f in path_files if f.startswith('pilon') and f.endswith('.jar')]
-        if pilon_jars:
-            return os.path.join(directory, sorted(pilon_jars)[-1])  # return the latest version
-    return None
-
-
 def get_nice_header(header):
     """
     For a header with a SPAdes/Velvet format, this function returns a simplified string that is
@@ -800,23 +738,6 @@ def remove_formatting(text):
     return re.sub('\033.*?m', '', text)
 
 
-def get_all_files_in_current_dir():
-    return [f for f in os.listdir('.') if os.path.isfile(f)]
-
-
-def convert_fastq_to_fasta(fastq, fasta):
-    open_func = get_open_function(fastq)
-    with open_func(fastq, 'rt') as fastq:
-        with open(fasta, 'wt') as fasta:
-            for line in fastq:
-                name = line.strip()[1:].split()[0]
-                sequence = next(fastq).strip()
-                _ = next(fastq)
-                _ = next(fastq)
-                fasta.write('>' + name + '\n')
-                fasta.write(sequence + '\n')
-
-
 def get_ascii_art():
     ascii_art = (bold_red("       __\n") +
                  bold_red("       \ \___\n") +
@@ -891,23 +812,9 @@ def spades_path_and_version(spades_path):
     if 'python version' in out and 'is not supported' in out:
         return found_spades_path, '', 'Python problem'
 
-    # Make sure SPAdes is 3.6.2+
+    # Make sure SPAdes is 3.13.1 or later
     try:
-        major_version = int(version.split('.')[0])
-        if major_version < 3:
-            status = 'too old'
-        else:
-            minor_version = int(version.split('.')[1])
-            if minor_version < 6:
-                status = 'too old'
-            elif minor_version > 6:
-                status = 'good'
-            else:  # minor_version == 6
-                patch_version = int(version.split('.')[2])
-                if patch_version < 2:
-                    status = 'too old'
-                else:
-                    status = 'good'
+        status = spades_status_from_version(version)
     except (ValueError, IndexError):
         version, status = '?', 'too old'
 
@@ -933,6 +840,21 @@ def spades_version_from_spades_output(spades_output):
     return ''
 
 
+def spades_status_from_version(version):
+    major_version = int(version.split('.')[0])
+    if major_version < 3:
+        return 'too old'
+    if major_version >= 4:
+        return 'too new'
+    assert major_version == 3
+
+    minor_version = int(version.split('.')[1])
+    if minor_version < 14:
+        return 'too old'
+    else:
+        return 'good'
+
+
 def racon_path_and_version(racon_path):
     found_racon_path = shutil.which(racon_path)
     if found_racon_path is None:
@@ -941,7 +863,7 @@ def racon_path_and_version(racon_path):
     process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
     out, _ = process.communicate()
     out = out.decode().lower()
-    if 'racon' not in out or  'options' not in out:
+    if 'racon' not in out or 'options' not in out:
         return found_racon_path, '-', 'bad'
 
     return found_racon_path, racon_version(found_racon_path), 'good'
@@ -952,9 +874,9 @@ def racon_version(found_racon_path):
     process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
     out, _ = process.communicate()
     out = out.decode().lower()
-    if out.startswith('v'):
-        return out[1:]
-    else:
+    try:
+        return re.search(r'(\d+\.\d+\.\d+)', out).group(1)
+    except (AttributeError, IndexError):
         return '-'
 
 
@@ -973,21 +895,6 @@ def makeblastdb_path_and_version(makeblastdb_path):
     return found_makeblastdb_path, version, 'good'
 
 
-def bcftools_path_and_version(bcftools_path):
-    found_bcftools_path = shutil.which(bcftools_path)
-    if found_bcftools_path is None:
-        return bcftools_path, '', 'not found'
-    command = [found_bcftools_path, '--version']
-    process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-    out, _ = process.communicate()
-    try:
-        version = out.decode().split('bcftools ')[1].split()[0]
-        int(version.split('.')[0]), int(version.split('.')[1])
-    except (ValueError, IndexError):
-        version, status = '?', 'too old'
-    return found_bcftools_path, version, 'good'
-
-
 def tblastn_path_and_version(tblastn_path):
     found_tblastn_path = shutil.which(tblastn_path)
     if found_tblastn_path is None:
@@ -1003,129 +910,6 @@ def tblastn_path_and_version(tblastn_path):
     return found_tblastn_path, version, 'good'
 
 
-def bowtie2_build_path_and_version(bowtie2_build_path):
-    found_bowtie2_build_path = shutil.which(bowtie2_build_path)
-    if found_bowtie2_build_path is None:
-        return bowtie2_build_path, '', 'not found'
-    command = [found_bowtie2_build_path, '--version']
-    process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-    out, _ = process.communicate()
-    try:
-        version = out.decode().split(' version ')[1].split()[0]
-        int(version.split('.')[0]), int(version.split('.')[1])
-    except (ValueError, IndexError):
-        version, status = '?', 'too old'
-    return found_bowtie2_build_path, version, 'good'
-
-
-def bowtie2_path_and_version(bowtie2_path):
-    found_bowtie2_path = shutil.which(bowtie2_path)
-    if found_bowtie2_path is None:
-        return bowtie2_path, '', 'not found'
-    command = [found_bowtie2_path, '--version']
-    process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-    out, _ = process.communicate()
-    try:
-        version = out.decode().split(' version ')[1].split()[0]
-        int(version.split('.')[0]), int(version.split('.')[1])
-    except (ValueError, IndexError):
-        version, status = '?', 'too old'
-    return found_bowtie2_path, version, 'good'
-
-
-def samtools_path_and_version(samtools_path):
-    found_samtools_path = shutil.which(samtools_path)
-    if found_samtools_path is None:
-        return samtools_path, '', 'not found'
-    command = [found_samtools_path]
-    process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-    out, _ = process.communicate()
-    version = out.decode().split('Version: ')[-1].split('-')[0].split()[0]
-
-    # Make sure Samtools is 1.0+
-    try:
-        major_version = int(version.split('.')[0])
-        if major_version < 1:
-            status = 'too old'
-        else:
-            status = 'good'
-    except (ValueError, IndexError):
-        version, status = '?', 'too old'
-    return found_samtools_path, version, status
-
-
-def java_path_and_version(java_path):
-    found_java_path = shutil.which(java_path)
-    if found_java_path is None:
-        return java_path, '', 'not found'
-
-    command = [found_java_path, '-version']
-    process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-    out, _ = process.communicate()
-    out = out.decode()
-    if 'no java runtime present' in out.lower():
-        return found_java_path, '?', 'bad'
-
-    version = java_version_from_java_output(out)
-
-    # Make sure Java is 1.7+
-    try:
-        if '.' in version:
-            major_version = int(version.split('.')[0])
-            if major_version < 1:
-                status = 'too old'
-            elif major_version > 1:
-                status = 'good'
-            else:  # major_version == 1
-                minor_version = int(version.split('.')[1])
-                if minor_version < 7:
-                    status = 'too old'
-                else:
-                    status = 'good'
-        elif '-' in version:
-            # E.g. '9-Ubuntu'
-            major_version = int(version.split('-')[0])
-            if major_version < 7:
-                status = 'too old'
-            else:
-                status = 'good'
-        else:
-            status = 'bad'
-    except (ValueError, IndexError):
-        status = 'bad'
-    return found_java_path, version, status
-
-
-def java_version_from_java_output(java_output):
-    """
-    Parses the Java version from the output of java -version
-    Thanks to @cerebis for this code.
-    """
-    version = re.search(r'^.* version[ \'"]+([^ \'"]+).*$', java_output, re.MULTILINE)
-    version = version.group(1) if version else ''
-    return version
-
-
-def pilon_path_and_version(pilon_path, java_path, args):
-    status = find_pilon(pilon_path, java_path, args)
-    if status == 'good':
-        pilon_path = args.pilon_path
-    else:
-        return pilon_path, '', status
-    if pilon_path.endswith('.jar'):
-        command = [java_path, '-jar', pilon_path, '--version']
-    else:
-        command = [pilon_path, '--version']
-    process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-    out, _ = process.communicate()
-    version = out.decode().split('Pilon version ')[-1].split()[0]
-    try:
-        int(version.split('.')[0]), int(version.split('.')[1])
-    except (ValueError, IndexError):
-        version, status = '?', 'too old'
-    return os.path.abspath(pilon_path), version, 'good'
-
-
 def line_iterator(string_with_line_breaks):
     """Iterates over a string containing line breaks, one line at a time."""
     prev_newline = -1
