@@ -48,11 +48,6 @@ FOUND_CONTIG_MAX_OVERLAP_SIZE = 250
 # the minimum threshold.
 MIN_LONG_READ_ALIGNMENT_LENGTH = 50
 
-# If less than this fraction of a read was aligned in the first aligning pass, Unicycler will try
-# again using much more sensitive alignment settings. This helps to align reads which come from
-# particularly difficult repetitive regions.
-MIN_READ_FRACTION_ALIGNED = 0.9
-
 # This is how much overlap is allowed between two alignments in a single read, relative to the
 # graph's overlap. For example, if the graph has an overlap of 95 and this value is 1.1,
 # then alignments within a read can go up to 105 bp, but alignments with more overlap will be
@@ -160,10 +155,6 @@ MAX_AUTO_THREAD_COUNT = 8
 # The default sequence line wrapping length (e.g. for use in FASTA files).
 BASES_PER_FASTA_LINE = 70
 
-# Pilon is run multiple times to polish things up as nice as possible. It will stop when no more
-# changes are made or this limit is hit.
-MAX_PILON_POLISH_COUNT = 10
-
 MINIASM_BRIDGE_QUAL_WITH_GRAPH_PATH = 1.0
 MINIASM_BRIDGE_QUAL_WITH_DEAD_END = 1.0
 MINIASM_BRIDGE_QUAL_WITHOUT_PATH_OR_DEAD_END = 0.7
@@ -181,3 +172,5 @@ REQUIRED_MINIASM_ASSEMBLY_SIZE_FOR_BRIDGING = 0.5
 # limits the amount of trimming it's willing to do. I.e. if miniasm trimmed more than this from a
 # contig, Unicycler won't.
 MAX_MINIASM_DEAD_END_TRIM_SIZE = 100
+
+MAX_SIMPLE_LOOP_SIZE = 10000
